@@ -123,7 +123,7 @@ void AttendeeLineEdit::keyPressEvent(QKeyEvent *ev)
     if ((ev->key() == Qt::Key_Enter || ev->key() == Qt::Key_Return)
         && !completionBox()->isVisible()) {
         Q_EMIT downPressed();
-        KPIM::AddresseeLineEdit::keyPressEvent(ev);
+        PimCommon::AddresseeLineEdit::keyPressEvent(ev);
     } else if (ev->key() == Qt::Key_Backspace && text().isEmpty()) {
         ev->accept();
         Q_EMIT deleteMe();
@@ -140,7 +140,7 @@ void AttendeeLineEdit::keyPressEvent(QKeyEvent *ev)
     } else if (ev->key() == Qt::Key_Up) {
         Q_EMIT upPressed();
     } else {
-        KPIM::AddresseeLineEdit::keyPressEvent(ev);
+        PimCommon::AddresseeLineEdit::keyPressEvent(ev);
     }
 }
 
@@ -156,15 +156,15 @@ AttendeeLine::AttendeeLine(QWidget *parent)
     setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
 
     QBoxLayout *topLayout = new QHBoxLayout(this);
-    topLayout->setMargin(0);
+    topLayout->setContentsMargins(0, 0, 0, 0);
     mRoleCombo->addItem(QIcon::fromTheme(QStringLiteral("meeting-participant")),
-                        KCalUtils::Stringify::attendeeRole(KCalCore::Attendee::ReqParticipant));
+                        KCalUtils::Stringify::attendeeRole(KCalendarCore::Attendee::ReqParticipant));
     mRoleCombo->addItem(QIcon::fromTheme(QStringLiteral("meeting-participant-optional")),
-                        KCalUtils::Stringify::attendeeRole(KCalCore::Attendee::OptParticipant));
+                        KCalUtils::Stringify::attendeeRole(KCalendarCore::Attendee::OptParticipant));
     mRoleCombo->addItem(QIcon::fromTheme(QStringLiteral("meeting-observer")),
-                        KCalUtils::Stringify::attendeeRole(KCalCore::Attendee::NonParticipant));
+                        KCalUtils::Stringify::attendeeRole(KCalendarCore::Attendee::NonParticipant));
     mRoleCombo->addItem(QIcon::fromTheme(QStringLiteral("meeting-chair")),
-                        KCalUtils::Stringify::attendeeRole(KCalCore::Attendee::Chair));
+                        KCalUtils::Stringify::attendeeRole(KCalendarCore::Attendee::Chair));
 
     mResponseCombo->addItem(QIcon::fromTheme(QStringLiteral(
                                                  "meeting-participant-request-response")),
@@ -271,7 +271,7 @@ void AttendeeLine::dataFromFields()
         return;
     }
 
-    KCalCore::Attendee::Ptr oldAttendee(mData->attendee());
+    KCalendarCore::Attendee oldAttendee(mData->attendee());
 
     QString email, name;
     KEmailAddress::extractEmailAddressAndName(mEdit->text(), email, name);
@@ -287,7 +287,7 @@ void AttendeeLine::dataFromFields()
     clearModified();
     if (!(oldAttendee == mData->attendee()) && !email.isEmpty()) {
         // if email is empty, we don't want to update anything
-        qCDebug(INCIDENCEEDITOR_LOG) << oldAttendee->email() << mData->email();
+        qCDebug(INCIDENCEEDITOR_LOG) << oldAttendee.email() << mData->email();
         Q_EMIT changed(oldAttendee, mData->attendee());
     }
 }
@@ -350,34 +350,6 @@ int AttendeeLine::setColumnWidth(int w)
 void AttendeeLine::setActions(AttendeeActions actions)
 {
     mStateCombo->clear();
-    return;
-    if (actions == EventActions) {
-        mStateCombo->addItem(QIcon::fromTheme(QStringLiteral("task-attention")),
-                             KCalUtils::Stringify::attendeeStatus(AttendeeData::NeedsAction));
-        mStateCombo->addItem(QIcon::fromTheme(QStringLiteral("task-accepted")),
-                             KCalUtils::Stringify::attendeeStatus(AttendeeData::Accepted));
-        mStateCombo->addItem(QIcon::fromTheme(QStringLiteral("task-reject")),
-                             KCalUtils::Stringify::attendeeStatus(AttendeeData::Declined));
-        mStateCombo->addItem(QIcon::fromTheme(QStringLiteral("task-attempt")),
-                             KCalUtils::Stringify::attendeeStatus(AttendeeData::Tentative));
-        mStateCombo->addItem(QIcon::fromTheme(QStringLiteral("task-delegate")),
-                             KCalUtils::Stringify::attendeeStatus(AttendeeData::Delegated));
-    } else {
-        mStateCombo->addItem(QIcon::fromTheme(QStringLiteral("task-attention")),
-                             KCalUtils::Stringify::attendeeStatus(AttendeeData::NeedsAction));
-        mStateCombo->addItem(QIcon::fromTheme(QStringLiteral("task-accepted")),
-                             KCalUtils::Stringify::attendeeStatus(AttendeeData::Accepted));
-        mStateCombo->addItem(QIcon::fromTheme(QStringLiteral("task-reject")),
-                             KCalUtils::Stringify::attendeeStatus(AttendeeData::Declined));
-        mStateCombo->addItem(QIcon::fromTheme(QStringLiteral("task-attempt")),
-                             KCalUtils::Stringify::attendeeStatus(AttendeeData::Tentative));
-        mStateCombo->addItem(QIcon::fromTheme(QStringLiteral("task-delegate")),
-                             KCalUtils::Stringify::attendeeStatus(AttendeeData::Delegated));
-        mStateCombo->addItem(QIcon::fromTheme(QStringLiteral("task-complete")),
-                             KCalUtils::Stringify::attendeeStatus(AttendeeData::Completed));
-        mStateCombo->addItem(QIcon::fromTheme(QStringLiteral("task-ongoing")),
-                             KCalUtils::Stringify::attendeeStatus(AttendeeData::InProcess));
-    }
 }
 
 void AttendeeLine::setCompletionMode(KCompletion::CompletionMode mode)
@@ -430,9 +402,7 @@ void AttendeeLine::aboutToBeDeleted()
         return;
     }
 
-    Q_EMIT changed(mData->attendee(),
-                   KCalCore::Attendee::Ptr(new KCalCore::Attendee(QLatin1String(""),
-                                                                  QLatin1String(""))));
+    Q_EMIT changed(mData->attendee(), KCalendarCore::Attendee(QLatin1String(""), QLatin1String("")));
 }
 
 bool AttendeeLine::canDeleteLineEdit() const
