@@ -23,7 +23,7 @@
 #include "attachmenticonview.h"
 #include "ui_dialogdesktop.h"
 
-#include <KdepimDBusInterfaces/UriHandler>
+#include <CalendarSupport/UriHandler>
 
 #include <KContacts/VCardDrag>
 
@@ -35,7 +35,9 @@
 #include <QMenu>
 #include <KMessageBox>
 #include <KProtocolManager>
-#include <KRun>
+#include <kio_version.h>
+#include <KIO/JobUiDelegate>
+#include <KIO/OpenUrlJob>
 #include <KIO/Job>
 #include <KIO/StoredTransferJob>
 #include <KJobWidgets>
@@ -167,7 +169,7 @@ void IncidenceAttachment::copyToClipboard()
 void IncidenceAttachment::openURL(const QUrl &url)
 {
     QString uri = url.url();
-    UriHandler::process(uri);
+    CalendarSupport::UriHandler::process(uri);
 }
 
 void IncidenceAttachment::pasteFromClipboard()
@@ -284,17 +286,17 @@ void IncidenceAttachment::showAttachment(QListWidgetItem *item)
     if (att.isUri()) {
         openURL(QUrl(att.uri()));
     } else {
-        KRun::RunFlags flags;
-        flags |= KRun::DeleteTemporaryFiles;
-        flags |= KRun::RunExecutables;
-        KRun::runUrl(attitem->tempFileForAttachment(), att.mimeType(), nullptr, flags);
+        KIO::OpenUrlJob *job = new KIO::OpenUrlJob(attitem->tempFileForAttachment(), att.mimeType());
+        job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, mAttachmentView));
+        job->setDeleteTemporaryFile(true);
+        job->setRunExecutables(true);
+        job->start();
     }
 }
 
 void IncidenceAttachment::showContextMenu(const QPoint &pos)
 {
-    QListWidgetItem *item = mAttachmentView->itemAt(pos);
-    const bool enable = item != nullptr;
+    const bool enable = mAttachmentView->itemAt(pos) != nullptr;
 
     int numSelected = 0;
     for (int itemIndex = 0; itemIndex < mAttachmentView->count(); ++itemIndex) {
@@ -407,14 +409,22 @@ void IncidenceAttachment::handlePasteOrDrop(const QMimeData *mimeData)
         //urls = QList<QUrl>::fromMimeData( mimeData, &metadata );
         probablyWeHaveUris = true;
         labels
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
             = metadata[QStringLiteral("labels")].split(QLatin1Char(':'), QString::SkipEmptyParts);
+#else
+            = metadata[QStringLiteral("labels")].split(QLatin1Char(':'), Qt::SkipEmptyParts);
+#endif
         const QStringList::Iterator end(labels.end());
         for (QStringList::Iterator it = labels.begin(); it != end; ++it) {
             *it = QUrl::fromPercentEncoding((*it).toLatin1());
         }
     } else if (mimeData->hasText()) {
         const QString text = mimeData->text();
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
         QStringList lst = text.split(QLatin1Char('\n'), QString::SkipEmptyParts);
+#else
+        QStringList lst = text.split(QLatin1Char('\n'), Qt::SkipEmptyParts);
+#endif
         urls.reserve(lst.count());
         QStringList::ConstIterator end(lst.constEnd());
         for (QStringList::ConstIterator it = lst.constBegin(); it != end; ++it) {
