@@ -32,7 +32,7 @@
 #include "editorconfig.h"
 #include "incidencedatetime.h"
 #include "schedulingdialog.h"
-#include "CalendarSupport/FreeBusyItemModel"
+#include <CalendarSupport/FreeBusyItemModel>
 #include "ui_dialogdesktop.h"
 
 #include <Akonadi/Contact/ContactGroupExpandJob>
@@ -454,10 +454,10 @@ void IncidenceAttendee::expandResult(KJob *job)
         dataModel()->removeRow(row);
         for (const KContacts::Addressee &member : groupMembers) {
             KCalendarCore::Attendee newAt(member.realName(), member.preferredEmail(),
-                                              attendee.RSVP(),
-                                              attendee.status(),
-                                              attendee.role(),
-                                              member.uid());
+                                          attendee.RSVP(),
+                                          attendee.status(),
+                                          attendee.role(),
+                                          member.uid());
             dataModel()->insertAttendee(row, newAt);
         }
     }
@@ -481,15 +481,15 @@ void IncidenceAttendee::slotSelectAddresses()
         dialog = new Akonadi::EmailAddressSelectionDialog(mParentWidget);
     }
     dialog->view()->view()->setSelectionMode(QAbstractItemView::ExtendedSelection);
-    dialog->setWindowTitle(i18n("Select Attendees"));
+    dialog->setWindowTitle(i18nc("@title:window", "Select Attendees"));
     connect(dialog.data(), &Akonadi::AbstractEmailAddressSelectionDialog::insertAddresses, this, &IncidenceEditorNG::IncidenceAttendee::insertAddresses);
     if (dialog->exec() == QDialog::Accepted) {
         const Akonadi::EmailAddressSelection::List list = dialog->selectedAddresses();
         for (const Akonadi::EmailAddressSelection &selection : list) {
             if (selection.item().hasPayload<KContacts::ContactGroup>()) {
                 Akonadi::ContactGroupExpandJob *job
-                        = new Akonadi::ContactGroupExpandJob(
-                            selection.item().payload<KContacts::ContactGroup>(), this);
+                    = new Akonadi::ContactGroupExpandJob(
+                          selection.item().payload<KContacts::ContactGroup>(), this);
                 connect(job, &Akonadi::ContactGroupExpandJob::result, this,
                         &IncidenceAttendee::expandResult);
                 KCalendarCore::Attendee::PartStat partStat = KCalendarCore::Attendee::NeedsAction;
@@ -497,10 +497,10 @@ void IncidenceAttendee::slotSelectAddresses()
 
                 int pos = 0;
                 KCalendarCore::Attendee newAt(selection.name(),
-                                                  selection.email(),
-                                                  rsvp,
-                                                  partStat,
-                                                  KCalendarCore::Attendee::ReqParticipant);
+                                              selection.email(),
+                                              rsvp,
+                                              partStat,
+                                              KCalendarCore::Attendee::ReqParticipant);
                 dataModel()->insertAttendee(pos, newAt);
 
                 mExpandGroupJobs.insert(job, newAt.uid());
@@ -811,10 +811,10 @@ void IncidenceAttendee::insertAttendeeFromAddressee(const KContacts::Addressee &
         rsvp = false;
     }
     KCalendarCore::Attendee newAt(a.realName(), a.preferredEmail(),
-                                                         rsvp,
-                                                         partStat,
-                                                         KCalendarCore::Attendee::ReqParticipant,
-                                                         a.uid());
+                                  rsvp,
+                                  partStat,
+                                  KCalendarCore::Attendee::ReqParticipant,
+                                  a.uid());
     if (pos < 0) {
         pos = dataModel()->rowCount() - 1;
     }
@@ -886,10 +886,10 @@ void IncidenceAttendee::slotOrganizerChanged(const QString &newOrganizer)
         if (newOrganizerAttendee == -1) {
             bool rsvp = !iAmOrganizer(); // if it is the user, don't make him rsvp.
             KCalendarCore::Attendee::PartStat status = iAmOrganizer() ? KCalendarCore::Attendee::Accepted
-                                                  : KCalendarCore::Attendee::NeedsAction;
+                                                       : KCalendarCore::Attendee::NeedsAction;
 
             KCalendarCore::Attendee newAt(name, email, rsvp, status,
-                                       KCalendarCore::Attendee::ReqParticipant);
+                                          KCalendarCore::Attendee::ReqParticipant);
 
             mDataModel->insertAttendee(mDataModel->rowCount(), newAt);
         }
@@ -1036,17 +1036,17 @@ void IncidenceAttendee::printDebugInfo() const
                                          << attendee.delegate()
                                          << attendee.delegator()
                                          << "; we have:";
-            for (int i = 0; i < newList.count(); ++i) {
-                KCalendarCore::Attendee attendee = newList[i];
-                qCDebug(INCIDENCEEDITOR_LOG) << "Attendee: " << attendee.email()
-                                             << attendee.name()
-                                             << attendee.status()
-                                             << attendee.RSVP()
-                                             << attendee.role()
-                                             << attendee.uid()
-                                             << attendee.cuType()
-                                             << attendee.delegate()
-                                             << attendee.delegator();
+            for (int i = 0, total = newList.count(); i < total; ++i) {
+                const KCalendarCore::Attendee newAttendee = newList[i];
+                qCDebug(INCIDENCEEDITOR_LOG) << "Attendee: " << newAttendee.email()
+                                             << newAttendee.name()
+                                             << newAttendee.status()
+                                             << newAttendee.RSVP()
+                                             << newAttendee.role()
+                                             << newAttendee.uid()
+                                             << newAttendee.cuType()
+                                             << newAttendee.delegate()
+                                             << newAttendee.delegator();
             }
 
             return;
