@@ -45,6 +45,7 @@
 #include <CollectionComboBox>
 #include <Item>
 #include <Akonadi/Calendar/ETMCalendar>
+#include <AkonadiCore/EntityTreeModel>
 
 #include <KCalendarCore/ICalFormat>
 #include <KCalendarCore/MemoryCalendar>
@@ -128,7 +129,7 @@ public:
 IncidenceDialogPrivate::IncidenceDialogPrivate(Akonadi::IncidenceChanger *changer, IncidenceDialog *qq)
     : q_ptr(qq)
     , mUi(new Ui::EventOrTodoDesktop)
-    , mCalSelector(new Akonadi::CollectionComboBox)
+    , mCalSelector(new Akonadi::CollectionComboBox(changer ? changer->entityTreeModel() : nullptr))
     , mCloseOnSave(false)
     , mItemManager(new EditorItemManager(this, changer))
     , mEditor(new CombinedIncidenceEditor(qq))
@@ -182,8 +183,8 @@ IncidenceDialogPrivate::IncidenceDialogPrivate(Akonadi::IncidenceChanger *change
     mIeResource = new IncidenceResource(mIeAttendee, mIeDateTime, mUi);
     mEditor->combine(mIeResource);
 
-    // Select calendar to last collection used, if valid; else select the default collection
-    const qint64 colId = IncidenceEditorNG::IncidenceEditorSettings::self()->lastSelectedFolder();
+    // Set the default collection
+    const qint64 colId = CalendarSupport::KCalPrefs::instance()->defaultCalendarId();
     const Akonadi::Collection col(colId);
     setCalendarCollection(col);
 
@@ -226,15 +227,7 @@ void IncidenceDialogPrivate::setCalendarCollection(const Akonadi::Collection &co
     if (collection.isValid()) {
         mCalSelector->setDefaultCollection(collection);
     } else {
-        // fallback to default collection
-        const qint64 defColId = CalendarSupport::KCalPrefs::instance()->defaultCalendarId();
-        const Akonadi::Collection defCol(defColId);
-        if (defCol.isValid()) {
-            mCalSelector->setDefaultCollection(defCol);
-        } else {
-            // Give up and use the first item in the selector
-            mCalSelector->setCurrentIndex(0);
-        }
+        mCalSelector->setCurrentIndex(0);
     }
 }
 
@@ -528,6 +521,28 @@ void IncidenceDialogPrivate::handleItemSaveFinish(EditorItemManager::SaveAction
 {
     Q_Q(IncidenceDialog);
 
+    if ((mEditor->type() == KCalendarCore::Incidence::TypeEvent) &&
+        (mCalSelector->count() > 1) &&
+        (CalendarSupport::KCalPrefs::instance()->defaultCalendarId() == -1)) {
+            const QString collectionName = mCalSelector->currentText();
+            const QString message =
+                xi18nc("@info",
+                      "<para>You have not set a default calendar for your events yet.</para>"
+                      "<para>Setting a default calendar will make creating new events faster and "
+                      "easier with less chance of filing them into the wrong folder.</para>"
+                      "<para>Would you like to set your default events calendar to "
+                      "<resource>%1</resource>?</para>",
+                      collectionName);
+          if (KMessageBox::questionYesNo(q,
+              message,
+              i18nc("@title:window", "Set Default Calendar?"),
+              KStandardGuiItem::yes(), // Make collectionName My Default Calendar
+              KStandardGuiItem::no(),  // Do Not Set a Default Calendar at this Time"
+              QStringLiteral("setDefaultCalendarCollection")) == KMessageBox::Yes) {
+              CalendarSupport::KCalPrefs::instance()->setDefaultCalendarId(mItem.storageCollectionId());
+          }
+    }
+
     if (mCloseOnSave) {
         q->accept();
     } else {
@@ -607,8 +622,8 @@ void IncidenceDialogPrivate::load(const Akonadi::Item &item)
 
     if (incidence->attendeeCount() > 1     // >1 because you won't drink alone
         && !me.isNull() && (me.status() == KCalendarCore::Attendee::NeedsAction
-                  || me.status() == KCalendarCore::Attendee::Tentative
-                  || me.status() == KCalendarCore::Attendee::InProcess)) {
+                            || me.status() == KCalendarCore::Attendee::Tentative
+                            || me.status() == KCalendarCore::Attendee::InProcess)) {
         // Show the invitation bar: "You are invited [accept] [decline]"
         mUi->mInvitationBar->show();
     } else {
@@ -623,10 +638,8 @@ void IncidenceDialogPrivate::load(const Akonadi::Item &item)
         mCalSelector->setDefaultCollection(Akonadi::Collection(item.storageCollectionId()));
     }
 
-    if (!mCalSelector->mimeTypeFilter().contains(QLatin1String("text/calendar"))
-        || !mCalSelector->mimeTypeFilter().contains(incidence->mimeType())) {
-        mCalSelector->setMimeTypeFilter(QStringList() << incidence->mimeType()
-                                                      << QStringLiteral("text/calendar"));
+    if (!mCalSelector->mimeTypeFilter().contains(incidence->mimeType())) {
+        mCalSelector->setMimeTypeFilter({incidence->mimeType()});
     }
 
     if (mEditor->type() == KCalendarCore::Incidence::TypeTodo) {
@@ -754,14 +767,6 @@ void IncidenceDialog::writeConfig()
 {
     KConfigGroup group(KSharedConfig::openConfig(), "IncidenceDialog");
     group.writeEntry("Size", size());
-
-    const Akonadi::Collection col = d_ptr->mCalSelector->currentCollection();
-    // col might not be valid if the collection wasn't found yet (the combo is async), skip saving in that case
-    if (col.isValid()
-        && col.id() != IncidenceEditorNG::IncidenceEditorSettings::self()->lastSelectedFolder()) {
-        IncidenceEditorNG::IncidenceEditorSettings::self()->setLastSelectedFolder(col.id());
-        IncidenceEditorNG::IncidenceEditorSettings::self()->save();
-    }
 }
 
 void IncidenceDialog::readConfig()
