@@ -23,8 +23,8 @@
 #include "resourcemanagement.h"
 #include "ui_resourcemanagement.h"
 #include "resourcemodel.h"
-#include "CalendarSupport/FreeBusyItem"
-#include "CalendarSupport/FreeBusyCalendar"
+#include <CalendarSupport/FreeBusyItem>
+#include <CalendarSupport/FreeBusyCalendar>
 #include "ldaputils.h"
 
 #include "freebusyganttproxymodel.h"
@@ -115,7 +115,7 @@ public:
 ResourceManagement::ResourceManagement(QWidget *parent)
     : QDialog(parent)
 {
-    setWindowTitle(i18n("Resource Management"));
+    setWindowTitle(i18nc("@title:window", "Resource Management"));
     QDialogButtonBox *buttonBox = new QDialogButtonBox(
         QDialogButtonBox::Ok | QDialogButtonBox::Close, this);
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
@@ -151,7 +151,7 @@ ResourceManagement::ResourceManagement(QWidget *parent)
     attrs << QStringLiteral("cn") << QStringLiteral("mail")
           << QStringLiteral("owner") << QStringLiteral("givenname") << QStringLiteral("sn")
           << QStringLiteral("kolabDescAttribute") << QStringLiteral("description");
-    ResourceModel *resourcemodel = new ResourceModel(attrs);
+    ResourceModel *resourcemodel = new ResourceModel(attrs, this);
     mUi->treeResults->setModel(resourcemodel);
 
     // This doesn't work till now :(-> that's why i use the click signal
