@@ -61,7 +61,7 @@ TemplateManagementDialog::TemplateManagementDialog(
     , m_changed(false)
 {
     QString m_type_translated = i18n(qPrintable(m_type));
-    setWindowTitle(i18n("Manage %1 Templates", m_type_translated));
+    setWindowTitle(i18nc("@title:window", "Manage %1 Templates", m_type_translated));
     QDialogButtonBox *buttonBox = new QDialogButtonBox(
         QDialogButtonBox::Ok | QDialogButtonBox::Cancel | QDialogButtonBox::Help, this);
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
@@ -183,7 +183,10 @@ void TemplateManagementDialog::slotRemoveTemplate()
 
     m_templates.removeAll(item->text());
     m_base.m_listBox->takeItem(current);
-    m_base.m_listBox->item(qMax(current - 1, 0))->setSelected(true);
+    QListWidgetItem *newItem = m_base.m_listBox->item(qMax(current - 1, 0));
+    if (newItem) {
+        newItem->setSelected(true);
+    }
 
     updateButtons();
 
